@@ -212,6 +212,15 @@ class Artist(Resource):
         """
         return self.get_paginated_list("albums", **kwargs)
 
+    def get_playlists(self, **kwargs) -> PaginatedList[Playlist]:
+        """
+        Get a list of artist's playlists.
+
+        :returns: a :class:`PaginatedList <deezer.pagination.PaginatedList>`
+                  of :class:`Playlist <deezer.resources.Playlist>` instances
+        """
+        return self.get_paginated_list("playlists", **kwargs)
+
 
 class Genre(Resource):
     """
@@ -237,6 +246,15 @@ class Genre(Resource):
         """
         return self.get_relation("artists", **kwargs)
 
+    def get_podcasts(self, **kwargs) -> PaginatedList[Podcast]:
+        """
+        Get all podcasts for a genre.
+
+        :returns: a :class:`PaginatedList <deezer.pagination.PaginatedList>`
+                  of :class:`Podcast <deezer.resources.Podcast>` instances
+        """
+        return self.get_paginated_list("podcasts", **kwargs)
+
     def get_radios(self, **kwargs) -> list[Radio]:
         """
         Get all radios for a genre.
@@ -462,7 +480,7 @@ class Chart(Resource):
 
     type = "chart"
 
-    id = 0
+    id: int
     tracks: list[Track]
     albums: list[Album]
     artists: list[Artist]
@@ -497,6 +515,13 @@ class Chart(Resource):
         """
         return self.get_paginated_list("playlists", **kwargs)
 
+    def get_podcasts(self, **kwargs) -> PaginatedList[Podcast]:
+        """
+        :returns: a :class:`PaginatedList <deezer.pagination.PaginatedList>`
+                  of :class:`Podcast <deezer.resources.Podcast>` instances
+        """
+        return self.get_paginated_list("podcasts", **kwargs)
+
 
 class Podcast(Resource):
     """
